@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.12';
+our $VERSION = '0.1201';
 
 use Moo;
 use strictures 2;
@@ -263,7 +263,8 @@ sub nrc_get_sentence {
 sub _tokenize {
     my ($sentence) = @_;
     $sentence =~ s/[[:punct:]]//g;  # Drop punctuation
-    my @words = split /\s+/, $sentence;
+    $sentence =~ s/\d//g;           # Drop digits
+    my @words = grep { $_ } split /\s+/, $sentence;
     return @words;
 }
 
@@ -293,7 +294,7 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.12
+version 0.1201
 
 =head1 SYNOPSIS
 
